@@ -7,7 +7,7 @@ from .stemmer import FindStems
 from .tokenizer import Tokenizer
 from .token_merger import ClassifierChunkParser
 # from .spell_checker import SpellCheck
-from .char_normalizer import Char_Normalizer
+from .charnormalizer import CharNormalizer
 from .date2string import Date2String
 from .time2string import Time2String
 from .num2string import Num2String
