@@ -697,17 +697,17 @@ class FindStems():
 
             self.verb_p2f_map, self.verb_f2p_map = self.verb_tense_map[0], self.verb_tense_map[1]
 
-        self.prefix_list = set({})
-        with open(self.prefix_list_path, "r", encoding='utf-8') as pishvand_input_file:
-            pishvandFile_content = pishvand_input_file.readlines()
-            for el in pishvandFile_content:
-                self.prefix_list.add(el.strip())
-
-        self.postfix_list = set({})
-        with open(self.postfix_list_path, "r", encoding='utf-8') as pasvand_input_file:
-            pasvandFile_content = pasvand_input_file.readlines()
-            for el in pasvandFile_content:
-                self.postfix_list.add(el.strip())
+        # self.prefix_list = set({})
+        # with open(self.prefix_list_path, "r", encoding='utf-8') as pishvand_input_file:
+        #     pishvandFile_content = pishvand_input_file.readlines()
+        #     for el in pishvandFile_content:
+        #         self.prefix_list.add(el.strip())
+        #
+        # self.postfix_list = set({})
+        # with open(self.postfix_list_path, "r", encoding='utf-8') as pasvand_input_file:
+        #     pasvandFile_content = pasvand_input_file.readlines()
+        #     for el in pasvandFile_content:
+        #         self.postfix_list.add(el.strip())
 
         with open(config_file) as f:
             self.affix_list = json.load(f)
@@ -784,7 +784,7 @@ class FindStems():
     def prefix_finder(self, word):
         prefix_tmp = []
         stem_candidate = word
-        prefix1, candidate_list = self.remove_prefixes(word, self.prefix_list)
+        prefix1, candidate_list = self.remove_prefixes(word, self.affix_list["prefix_all"])
 
         prefix_tmp.append(prefix1)
         prefix_tmp = list(filter(('').__ne__, prefix_tmp))
@@ -808,7 +808,7 @@ class FindStems():
     def irregular_postfix(self, word):
 
         postfix_irregular = []
-        postfix, candidate_list = self.remove_postfixes(word, self.postfix_list)
+        postfix, candidate_list = self.remove_postfixes(word, self.affix_list["irregular_postfix_all"])
 
         postfix_irregular.append(postfix)
         postfix_irregular = list(filter(('').__ne__, postfix_irregular))
@@ -1272,7 +1272,7 @@ class FindStems():
                 if pos in self.affix_list["postfix_joint"] + self.affix_list["irregular_postfix_joint"]:
                     text += pos
                 elif pos != "":
-                    text = text + " " + pos
+                    text = text + "\u200c" + pos
                 for i in reversed(postfix_tmp):
                     if self.double_postfix_joint and len(postfix_tmp) == 2 and postfix_tmp[1] in self.affix_list[
                         "plural_postfix_all"] and \
@@ -1280,22 +1280,25 @@ class FindStems():
                         if postfix_tmp[1] in self.affix_list["postfix_joint"]:
                             text += postfix_tmp[1] + "\u200c" + postfix_tmp[0]
                         else:
-                            text += ' ' + postfix_tmp[1] + "\u200c" + postfix_tmp[0]
+                            text += '\u200c' + postfix_tmp[1] + "\u200c" + postfix_tmp[0]
 
                         break
                     if i in self.affix_list["postfix_joint"] + self.affix_list["irregular_postfix_joint"]:
                         text += i
                     else:
-                        text += ' ' + i
+                        text += '\u200c' + i
 
-                return text + ' '
+                return text + '\u200c'
             #
 
             new_word, pos = self.irregular_postfix(word)
 
             if new_word in self.noun_lexicon:
                 text = ''
-                text += self.map_irregular_noun(new_word) + ' ' + pos
+                if pos in self.affix_list["postfix_joint"] + self.affix_list["irregular_postfix_joint"]:
+                    text += self.map_irregular_noun(new_word)  + pos
+                else:
+                    text += self.map_irregular_noun(new_word) + '\u200c' + pos
                 return text
 
             postfix, candidate_list = self.remove_postfixes(new_word, ["گ"])
@@ -1316,7 +1319,7 @@ class FindStems():
                 new_word = stem_candidate
 
             prefix_tmp = []
-            prefix1, candidate_list = self.remove_prefixes(word, self.prefix_list)
+            prefix1, candidate_list = self.remove_prefixes(word, self.affix_list["prefix_all"])
             prefix_tmp.append(prefix1)
             prefix_tmp = list(filter(('').__ne__, prefix_tmp))
 
@@ -1332,11 +1335,17 @@ class FindStems():
                 new_word = stem_candidate
 
             if new_word in self.noun_lexicon and len(prefix_tmp) != 0:
+                if prefix_tmp[0] in self.affix_list["prefix_joint"] :
+                    text = str(prefix_tmp[0])
+                else:
+                    text = str(prefix_tmp[0]) + '\u200c'
 
-                text = str(prefix_tmp[0]) + ' '
-                text += self.map_irregular_noun(new_word) + ' '
+                text += self.map_irregular_noun(new_word)
                 for i in reversed(postfix_tmp):
-                    text += i + ' '
+                    if i in self.affix_list["postfix_joint"] + self.affix_list["irregular_postfix_joint"]:
+                        text +=i
+                    else:
+                        text =  text + '\u200c'
 
                 return text
 
